Interface: TypedRegistry | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: TypedRegistry<T>

## # Type parameters

Name
`T`

## # Methods

### # get

▸ get(`id`): `T`

#### # Parameters

Name | Type
--- | ---
`id` | `string`

#### # Returns

`T`

#### # Defined in

index.esm.d.ts:1389
(opens new window)

### # register

▸ register(`item`): `string`

#### # Parameters

Name | Type
--- | ---
`item` | `ChartComponent`

#### # Returns

`string`

The scope where items defaults were registered to.

#### # Defined in

index.esm.d.ts:1388
(opens new window)

### # unregister

▸ unregister(`item`): `void`

#### # Parameters

Name | Type
--- | ---
`item` | `ChartComponent`

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1390
(opens new window)